Crate cot_macros

Crate cot_macros 

Macros

query

Attribute Macros

cachetest
dbtest
e2e_test
filter_fn
A macro attribute to write custom filters for askama templates.
main
model
Implement the Model trait for a struct.
test
An attribute macro that defines an async test function for a Cot-powered app.

Derive Macros

AdminModel
ApiOperationResponse
Form
FromRequestHead
IntoResponse
ModelHelper
SelectAsFormField
SelectChoice
Template
The Template derive macro and its template() attribute.